cis_config: Class Hierarchy

cis_config

Class Hierarchy
This inheritance list is sorted roughly, but not completely, alphabetically:
[detail level 123]

C asciiFile_t | Structure containing information about an ASCII text file
C asciiTable_t | Structure containing information about an ASCII table
▼C CisInput | Flag for checking if CisInterface.hpp has already been included
▼C CisAsciiFileInput | C++ interface to cisAsciiFileInput_t functionality. The CisAsciiFileInput class is a basic wrapper around the C cisAsciiFileInput_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic ASCII file input operations
C CisAsciiArrayInput | C++ interface to cisAsciiTableInput_t functionality for arrays
C CisAsciiArrayInput_local | C++ interface to cisAsciiTableInput_t functionality for local files as arrays
C CisAsciiFileInput_local | C++ interface to cisAsciiFileInput_t functionality for local files. The CisAsciiFileInput_local class is a basic wrapper around the C cisAsciiFileInput_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic ASCII file input operations
C CisAsciiTableInput | C++ interface to cisAsciiTableInput_t functionality
C CisAsciiTableInput_local | C++ interface to cisAsciiTableInput_t functionality for local files
C CisObjInput | C++ interface to cisObjInput_t functionality. The CisObjInput class is a basic wrapper around the C cisObjInput_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic ASCII file input operations
C CisPlyInput | C++ interface to cisPlyInput_t functionality. The CisPlyInput class is a basic wrapper around the C cisPlyInput_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic ASCII file input operations
▼C CisOutput | C++ interface to cisOutput_t functionality
▼C CisAsciiFileOutput | C++ interface to cisAsciiFileOutput_t functionality. The CisAsciiFileOutput class is a basic wrapper around the C cisAsciiFileOutput_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic ASCII file output operations
C CisAsciiArrayOutput | C++ interface to cisAsciiTableOutput_t functionality with arrays
C CisAsciiArrayOutput_local | C++ interface to cisAsciiTableOutput_t functionality for local files
C CisAsciiFileOutput_local | C++ interface to cisAsciiFileOutput_t functionality for local files. The CisAsciiFileOutput_local class is a basic wrapper around the C cisAsciiFileOutput_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic ASCII file output operations
C CisAsciiTableOutput | C++ interface to cisAsciiTableOutput_t functionality
C CisAsciiTableOutput_local | C++ interface to cisAsciiTableOutput_t functionality for local files
C CisObjOutput | C++ interface to cisObjOutput_t functionality. The CisObjOutput class is a basic wrapper around the C cisObjOutput_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic ASCII file output operations
C CisPlyOutput | C++ interface to cisPlyOutput_t functionality. The CisPlyOutput class is a basic wrapper around the C cisPlyOutput_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic ASCII file output operations
▼C CisRpc | C++ interface to cisRpc_t functionality
C CisRpcClient | C++ interface to cisRpc_t client-side functionality. The CisRpcClient class is a basic wrapper around the C cisRpc_t structure and associated client-side functions from the CisInterface.h header. It provides the user with C++ style access to basic RPC client operations
C CisRpcServer | C++ interface to cisRpc_t server-side functionality. The CisRpcServer class is a basic wrapper around the C cisRpc_t structure and associated server-side functions from the CisInterface.h header. It provides the user with C++ style access to basic RPC server operations
C comm_head_t | Header information passed by comms for multipart messages
C comm_t | Communication structure
C obj_t | Obj structure
C ply_t | Ply structure
C seri_t | Serializer structure